package com.example.panicbutton

import android.content.Intent
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.input.TextFieldValue
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            MyApp()
        }
    }
}

@Composable
fun MyApp() {
    val context = LocalContext.current
    var message by remember { mutableStateOf("Klik tombol untuk mengirim notifikasi") }
    var selectedConditions by remember { mutableStateOf(mutableSetOf<String>()) }
    var additionalNotes by remember { mutableStateOf(TextFieldValue("")) }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.Start
    ) {
        // Judul
        Text(
            text = "Terjadi Kondisi Darurat",
            fontSize = 20.sp,
            color = Color.Black, // Default text color is black
            modifier = Modifier.padding(bottom = 16.dp)
        )

        // Pilihan checkbox
        listOf("Kebakaran", "Banjir", "Gempa Bumi", "Huru hara/Demonstrasi", "Lainnya").forEach { condition ->
            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .clickable {
                        selectedConditions = selectedConditions.toMutableSet().apply {
                            if (contains(condition)) remove(condition) else add(condition)
                        }
                    }
                    .padding(vertical = 4.dp),
                verticalAlignment = Alignment.CenterVertically
            ) {
                Checkbox(
                    checked = selectedConditions.contains(condition),
                    onCheckedChange = { isChecked ->
                        selectedConditions = selectedConditions.toMutableSet().apply {
                            if (isChecked) add(condition) else remove(condition)
                        }
                    }
                )
                Text(
                    text = condition,
                    modifier = Modifier.padding(start = 8.dp),
                    color = Color.Black // Default text color is black
                )
            }
        }

        // Catatan tambahan
        Spacer(modifier = Modifier.height(16.dp))
        Text(text = "Catatan tambahan:", color = Color.Black)
        BasicTextField(
            value = additionalNotes,
            onValueChange = { additionalNotes = it },
            modifier = Modifier
                .fillMaxWidth()
                .height(100.dp)
                .padding(8.dp)
                .border(1.dp, Color.Gray),
            keyboardOptions = KeyboardOptions(imeAction = ImeAction.Done)
        )

        // Tombol Kirim
        Spacer(modifier = Modifier.height(16.dp))
        Button(
            onClick = {
                val notes = additionalNotes.text
                val conditions = selectedConditions.joinToString(", ")
                val report = "Kondisi: $conditions\nCatatan: $notes"
                sendNotification(report) { response ->
                    message = response
                }
            },
            colors = ButtonDefaults.buttonColors(containerColor = Color.Red)
        ) {
            Text(text = "Kirim Laporan", color = Color.White)
        }

        // Tombol untuk membuka activity baru
        Spacer(modifier = Modifier.height(16.dp))
        Button(
            onClick = {
                val intent = Intent(context, EvacuationPointsActivity::class.java)
                context.startActivity(intent)
            }
        ) {
            Text(text = "Lihat Titik Kumpul", color = Color.Black)
        }

        // Pesan besar
        Spacer(modifier = Modifier.height(16.dp))
        Text(
            text = "“JANGAN PANIK! SEGERA EVAKUASI\nDIRI ANDA KE TITIK KUMPUL”",
            color = Color.Red,
            fontSize = 15.sp
        )

        // Hasil request
        Spacer(modifier = Modifier.height(16.dp))
        Text(text = message, Modifier.padding(top = 16.dp), color = Color.Black)
    }
}

// Fungsi untuk mengirimkan HTTP request
fun sendNotification(report: String, onResult: (String) -> Unit) {
    // Simulasi fungsi untuk mengirim HTTP request
    onResult("Notifikasi berhasil dikirim!")
}
